"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QMdiSubWindow(QWidget):
    """
    https://doc.qt.io/qt-6/qmdisubwindow.html

    **Detailed Description**

    QMdiSubWindow represents a top-level window in a **QMdiArea** , and consists
    of a title bar with window decorations, an internal widget, and (depending
    on the current style) a window frame and a size grip. QMdiSubWindow has its
    own layout, which consists of the title bar and a center area for the
    internal widget.

    ![](images/qmdisubwindowlayout.png)

    The most common way to construct a QMdiSubWindow is to call
    **QMdiArea::addSubWindow** () with the internal widget as the argument. You
    can also create a subwindow yourself, and set an internal widget by calling
    **setWidget** ().

    You use the same API when programming with subwindows as with regular top-
    level windows (e.g., you can call functions such as **show** (), **hide**
    (), **showMaximized** (), and **setWindowTitle** ()).

    **Subwindow Handling**

    QMdiSubWindow also supports behavior specific to subwindows in an MDI area.

    By default, each QMdiSubWindow is visible inside the MDI area viewport when
    moved around, but it is also possible to specify transparent window movement
    and resizing behavior, where only the outline of a subwindow is updated
    during these operations. The **setOption** () function is used to enable
    this behavior.

    The **isShaded** () function detects whether the subwindow is currently
    shaded (i.e., the window is collapsed so that only the title bar is
    visible). To enter shaded mode, call **showShaded** (). QMdiSubWindow emits
    the **windowStateChanged** () signal whenever the window state has changed
    (e.g., when the window becomes minimized, or is restored). It also emits
    **aboutToActivate** () before it is activated.

    In keyboard-interactive mode, the windows are moved and resized with the
    keyboard. You can enter this mode through the system menu of the window. The
    **keyboardSingleStep**  and **keyboardPageStep**  properties control the
    distance the widget is moved or resized for each keypress event. When shift
    is pressed down page step is used; otherwise single step is used.

    You can also change the active window with the keyboard. By pressing the
    control and tab keys at the same time, the next (using the current
    **WindowOrder** ) subwindow will be activated. By pressing control, shift,
    and tab, you will activate the previous window. This is equivalent to
    calling **activateNextSubWindow** () and **activatePreviousSubWindow** ().
    Note that these shortcuts overrides global shortcuts, but not the
    **QMdiArea** s shortcuts.

    **See also** **QMdiArea** .
    """

    class SubWindowOption(enum.Flag):
        RubberBandResize: QMdiSubWindow = ...
        RubberBandMove: QMdiSubWindow = ...

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#QMdiSubWindow

        **QMdiSubWindow::QMdiSubWindow(QWidget * parent = nullptr,
        Qt::WindowFlags flags = Qt::WindowFlags())**

        Constructs a new QMdiSubWindow widget. The **parent** and **flags**
        arguments are passed to **QWidget** 's constructor.

        Instead of using addSubWindow(), it is also simply possible to use
        **setParent** () when you add the subwindow to a **QMdiArea** .

        Note that only **QMdiSubWindow** s can be set as children of
        **QMdiArea** ; you cannot, for instance, write:

        //bad code
            **QMdiArea**  mdiArea;
            **QTextEdit**
        editor(&mdiArea); // invalid child widget

        **See also** **QMdiArea::addSubWindow** ().
        """
        ...

    def childEvent(self, childEvent: QtCore.QChildEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#childEvent

        **[override virtual protected] void
        QMdiSubWindow::childEvent(QChildEvent * childEvent )**

        Reimplements: **QObject::childEvent** (QChildEvent *event).
        """
        ...

    def focusOutEvent(self, focusOutEvent: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#focusOutEvent

        **[override virtual protected] void
        QMdiSubWindow::focusOutEvent(QFocusEvent * focusOutEvent )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, focusInEvent: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#focusInEvent

        **[override virtual protected] void
        QMdiSubWindow::focusInEvent(QFocusEvent * focusInEvent )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def contextMenuEvent(self, contextMenuEvent: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#contextMenuEvent

        **[override virtual protected] void
        QMdiSubWindow::contextMenuEvent(QContextMenuEvent * contextMenuEvent )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def keyPressEvent(self, keyEvent: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#keyPressEvent

        **[override virtual protected] void
        QMdiSubWindow::keyPressEvent(QKeyEvent * keyEvent )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def mouseMoveEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#mouseMoveEvent

        **[override virtual protected] void
        QMdiSubWindow::mouseMoveEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#mouseReleaseEvent

        **[override virtual protected] void
        QMdiSubWindow::mouseReleaseEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mouseDoubleClickEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QMdiSubWindow::mouseDoubleClickEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mouseDoubleClickEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#mousePressEvent

        **[override virtual protected] void
        QMdiSubWindow::mousePressEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def paintEvent(self, paintEvent: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#paintEvent

        **[override virtual protected] void
        QMdiSubWindow::paintEvent(QPaintEvent * paintEvent )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def moveEvent(self, moveEvent: QtGui.QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#moveEvent

        **[override virtual protected] void QMdiSubWindow::moveEvent(QMoveEvent
        * moveEvent )**

        Reimplements: **QWidget::moveEvent** (QMoveEvent *event).
        """
        ...

    def timerEvent(self, timerEvent: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#timerEvent

        **[override virtual protected] void
        QMdiSubWindow::timerEvent(QTimerEvent * timerEvent )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def resizeEvent(self, resizeEvent: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#resizeEvent

        **[override virtual protected] void
        QMdiSubWindow::resizeEvent(QResizeEvent * resizeEvent )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).

        **Warning:** When maximizing or restoring a subwindow, the resulting
        call to this function may have an invalid **QResizeEvent::oldSize** ().
        """
        ...

    def leaveEvent(self, leaveEvent: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#leaveEvent

        **[override virtual protected] void QMdiSubWindow::leaveEvent(QEvent *
        leaveEvent )**

        Reimplements: **QWidget::leaveEvent** (QEvent *event).
        """
        ...

    def closeEvent(self, closeEvent: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#closeEvent

        **[override virtual protected] void
        QMdiSubWindow::closeEvent(QCloseEvent * closeEvent )**

        Reimplements: **QWidget::closeEvent** (QCloseEvent *event).
        """
        ...

    def changeEvent(self, changeEvent: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#changeEvent

        **[override virtual protected] void QMdiSubWindow::changeEvent(QEvent *
        changeEvent )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def hideEvent(self, hideEvent: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#hideEvent

        **[override virtual protected] void QMdiSubWindow::hideEvent(QHideEvent
        * hideEvent )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, showEvent: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#showEvent

        **[override virtual protected] void QMdiSubWindow::showEvent(QShowEvent
        * showEvent )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#event

        **[override virtual protected] bool QMdiSubWindow::event(QEvent * event
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#eventFilter

        **[override virtual protected] bool QMdiSubWindow::eventFilter(QObject *
        object , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def showShaded(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#showShaded

        **[slot] void QMdiSubWindow::showShaded()**

        Calling this function makes the subwindow enter the shaded mode. When
        the subwindow is shaded, only the title bar is visible.

        Although shading is not supported by all styles, this function will
        still show the subwindow as shaded, regardless of whether support for
        shading is available. However, when used with styles without shading
        support, the user will be unable to return from shaded mode through the
        user interface (e.g., through a shade button in the title bar).

        **See also** **isShaded** ().
        """
        ...

    def showSystemMenu(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#showSystemMenu

        **[slot] void QMdiSubWindow::showSystemMenu()**

        Shows the system menu below the system menu icon in the title bar.

        **See also** **setSystemMenu** () and **systemMenu** ().
        """
        ...

    def mdiArea(self) -> QMdiArea:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#mdiArea

        **QMdiArea *QMdiSubWindow::mdiArea() const**

        Returns the area containing this sub-window, or `nullptr` if there is
        none.

        **See also** **QMdiArea::addSubWindow** ().
        """
        ...

    def systemMenu(self) -> "QMenu":
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#systemMenu

        **QMenu *QMdiSubWindow::systemMenu() const**

        Returns a pointer to the current system menu, or zero if no system menu
        is set. **QMdiSubWindow**  provides a default system menu, but you can
        also set the menu with **setSystemMenu** ().

        **See also** **setSystemMenu** () and **showSystemMenu** ().
        """
        ...

    def setSystemMenu(self, systemMenu: "QMenu") -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#setSystemMenu

        **void QMdiSubWindow::setSystemMenu(QMenu * systemMenu )**

        Sets **systemMenu** as the current system menu for this subwindow.

        By default, each **QMdiSubWindow**  has a standard system menu.

        QActions for the system menu created by **QMdiSubWindow**  will
        automatically be updated depending on the current window state; e.g.,
        the minimize action will be disabled after the window is minimized.

        QActions added by the user are not updated by **QMdiSubWindow** .

        **QMdiSubWindow**  takes ownership of **systemMenu** ; you do not have
        to delete it. Any existing menus will be deleted.

        **See also** **systemMenu** () and **showSystemMenu** ().
        """
        ...

    def keyboardPageStep(self) -> int:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#keyboardPageStep-prop

        **keyboardPageStep : int**

        sets how far a widget should move or resize when using the keyboard page
        keys.

        When in keyboard-interactive mode, you can use the arrow and page keys
        to either move or resize the window. This property controls the page
        keys. The common way to enter keyboard interactive mode is to enter the
        subwindow menu, and select either "resize" or "move".

        The default keyboard page step value is 20 pixels.

        **Access functions:**

        int **keyboardPageStep** () const
        void **setKeyboardPageStep** (int
        **step** )

        **See also** **keyboardSingleStep** .
        """
        ...

    def setKeyboardPageStep(self, step: int) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#keyboardPageStep-prop

        **keyboardPageStep : int**

        sets how far a widget should move or resize when using the keyboard page
        keys.

        When in keyboard-interactive mode, you can use the arrow and page keys
        to either move or resize the window. This property controls the page
        keys. The common way to enter keyboard interactive mode is to enter the
        subwindow menu, and select either "resize" or "move".

        The default keyboard page step value is 20 pixels.

        **Access functions:**

        int **keyboardPageStep** () const
        void **setKeyboardPageStep** (int
        **step** )

        **See also** **keyboardSingleStep** .
        """
        ...

    def keyboardSingleStep(self) -> int:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#keyboardSingleStep-prop

        **keyboardSingleStep : int**

        sets how far a widget should move or resize when using the keyboard
        arrow keys.

        When in keyboard-interactive mode, you can use the arrow and page keys
        to either move or resize the window. This property controls the arrow
        keys. The common way to enter keyboard interactive mode is to enter the
        subwindow menu, and select either "resize" or "move".

        The default keyboard single step value is 5 pixels.

        **Access functions:**

        int **keyboardSingleStep** () const
        void **setKeyboardSingleStep**
        (int **step** )

        **See also** **keyboardPageStep** .

        **Member Function Documentation**
        """
        ...

    def setKeyboardSingleStep(self, step: int) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#keyboardSingleStep-prop

        **keyboardSingleStep : int**

        sets how far a widget should move or resize when using the keyboard
        arrow keys.

        When in keyboard-interactive mode, you can use the arrow and page keys
        to either move or resize the window. This property controls the arrow
        keys. The common way to enter keyboard interactive mode is to enter the
        subwindow menu, and select either "resize" or "move".

        The default keyboard single step value is 5 pixels.

        **Access functions:**

        int **keyboardSingleStep** () const
        void **setKeyboardSingleStep**
        (int **step** )

        **See also** **keyboardPageStep** .

        **Member Function Documentation**
        """
        ...

    def testOption(self, a0: "QMdiSubWindow.SubWindowOption") -> bool:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#testOption

        **bool QMdiSubWindow::testOption(QMdiSubWindow::SubWindowOption option )
        const**

        Returns `true` if **option** is enabled; otherwise returns `false`.

        **See also** **SubWindowOption**  and **setOption** ().
        """
        ...

    def setOption(
        self, option: "QMdiSubWindow.SubWindowOption", on: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#setOption

        **void QMdiSubWindow::setOption(QMdiSubWindow::SubWindowOption option ,
        bool on = true)**

        If **on** is true, **option** is enabled on the subwindow; otherwise it
        is disabled. See **SubWindowOption**  for the effect of each option.

        **See also** **SubWindowOption**  and **testOption** ().
        """
        ...

    def isShaded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#isShaded

        **bool QMdiSubWindow::isShaded() const**

        Returns `true` if this window is shaded; otherwise returns `false`.

        A window is shaded if it is collapsed so that only the title bar is
        visible.
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#widget

        **QWidget *QMdiSubWindow::widget() const**

        Returns the current internal widget.

        **See also** **setWidget** ().
        """
        ...

    def setWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#setWidget

        **void QMdiSubWindow::setWidget(QWidget * widget )**

        Sets **widget** as the internal widget of this subwindow. The internal
        widget is displayed in the center of the subwindow beneath the title
        bar.

        **QMdiSubWindow**  takes temporary ownership of **widget** ; you do not
        have to delete it. Any existing internal widget will be removed and
        reparented to the root window.

        **See also** **widget** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#minimumSizeHint

        **[override virtual] QSize QMdiSubWindow::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#sizeHint

        **[override virtual] QSize QMdiSubWindow::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    @property
    def aboutToActivate(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#aboutToActivate

        **[signal] void QMdiSubWindow::aboutToActivate()**

        **QMdiSubWindow**  emits this signal immediately before it is activated.
        After the subwindow has been activated, the **QMdiArea**  that manages
        the subwindow will also emit the **subWindowActivated** () signal.

        **See also** **QMdiArea::subWindowActivated** ().
        """
        ...

    @property
    def windowStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmdisubwindow.html#windowStateChanged

        **[signal] void QMdiSubWindow::windowStateChanged(Qt::WindowStates
        oldState , Qt::WindowStates newState )**

        **QMdiSubWindow**  emits this signal after the window state changes.
        **oldState** is the window state before it changed, and **newState** is
        the new, current state.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QPyDesignerCustomWidgetCollectionPlugin(
    QtCore.QObject, QDesignerCustomWidgetCollectionInterface
):
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtGui import *


class QTextList(QTextBlockGroup):
    """
    https://doc.qt.io/qt-6/qtextlist.html

    **Detailed Description**

    A list contains a sequence of text blocks, each of which is marked with a
    bullet point or other symbol. Multiple levels of lists can be used, and the
    automatic numbering feature provides support for ordered numeric and
    alphabetical lists.

    Lists are created by using a text cursor to insert an empty list at the
    current position or by moving existing text into a new list. The
    **QTextCursor::insertList** () function inserts an empty block into the
    document at the cursor position, and makes it the first item in a list.

    **QTextListFormat**  listFormat;
            if (list) {
                listFormat
    = list->format();
                listFormat.setIndent(listFormat.indent() + 1);
    }

            listFormat.setStyle(**QTextListFormat** ::ListDisc);
    cursor.insertList(listFormat);

    The **QTextCursor::createList** () function takes the contents of the
    cursor's current block and turns it into the first item of a new list.

    The cursor's current list is found with **QTextCursor::currentList** ().

    The number of items in a list is given by **count** (). Each item can be
    obtained by its index in the list with the **item** () function. Similarly,
    the index of a given item can be found with **itemNumber** (). The text of
    each item can be found with the **itemText** () function.

    Note that the items in the list may not be adjacent elements in the
    document. For example, the top-level items in a multi-level list will be
    separated by the items in lower levels of the list.

    List items can be deleted by index with the **removeItem** () function.
    **remove** () deletes the specified item in the list.

    The list's format is set with **setFormat** () and read with **format** ().
    The format describes the decoration of the list itself, and not the
    individual items.

    **See also** **QTextBlock** , **QTextListFormat** , and **QTextCursor** .
    """

    def __init__(self, doc: QTextDocument) -> None:
        ...

    def setFormat(self, aformat: QTextListFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtextlist.html#setFormat

        **void QTextList::setFormat(const QTextListFormat & format )**

        Sets the list's format to **format**.

        **See also** **format** ().
        """
        ...

    def format(self) -> QTextListFormat:
        """
        https://doc.qt.io/qt-6/qtextlist.html#format

        **QTextListFormat QTextList::format() const**

        Returns the list's format.

        **See also** **setFormat** ().
        """
        ...

    def add(self, block: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextlist.html#add

        **void QTextList::add(const QTextBlock & block )**

        Makes the given **block** part of the list.

        **See also** **remove** () and **removeItem** ().
        """
        ...

    def remove(self, a0: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextlist.html#remove

        **void QTextList::remove(const QTextBlock & block )**

        Removes the given **block** from the list.

        **See also** **add** () and **removeItem** ().
        """
        ...

    def removeItem(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextlist.html#removeItem

        **void QTextList::removeItem(int i )**

        Removes the item at item position **i** from the list. When the last
        item in the list is removed, the list is automatically deleted by the
        **QTextDocument**  that owns it.

        **See also** **add** () and **remove** ().
        """
        ...

    def itemText(self, a0: "QTextBlock") -> str:
        """
        https://doc.qt.io/qt-6/qtextlist.html#itemText

        **QString QTextList::itemText(const QTextBlock & block ) const**

        Returns the text of the list item that corresponds to the given
        **block**.
        """
        ...

    def itemNumber(self, a0: "QTextBlock") -> int:
        """
        https://doc.qt.io/qt-6/qtextlist.html#itemNumber

        **int QTextList::itemNumber(const QTextBlock & block ) const**

        Returns the index of the list item that corresponds to the given
        **block**. Returns -1 if the block was not present in the list.
        """
        ...

    def item(self, i: int) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextlist.html#item

        **QTextBlock QTextList::item(int i ) const**

        Returns the **i** -th text block in the list.

        **See also** **count** () and **itemText** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextlist.html#count

        **int QTextList::count() const**

        Returns the number of items in the list.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QSslKey(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslkey.html

    **Detailed Description**

    QSslKey provides a simple API for managing keys.

    **See also** **QSslSocket** , **QSslCertificate** , and **QSslCipher** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#QSslKey

        **QSslKey::QSslKey()**

        Constructs a null key.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        encoded: QtCore.QByteArray,
        algorithm: QSsl.KeyAlgorithm,
        encoding: QSsl.EncodingFormat = ...,
        type: QSsl.KeyType = ...,
        passPhrase: QtCore.QByteArray = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#QSslKey-1

        **QSslKey::QSslKey(const QByteArray & encoded , QSsl::KeyAlgorithm
        algorithm , QSsl::EncodingFormat encoding = QSsl::Pem, QSsl::KeyType
        type = QSsl::PrivateKey, const QByteArray & passPhrase = QByteArray())**

        Constructs a QSslKey by decoding the string in the byte array
        **encoded** using a specified **algorithm** and **encoding** format.
        **type** specifies whether the key is public or private.

        If the key is encrypted then **passPhrase** is used to decrypt it.

        After construction, use **isNull** () to check if **encoded** contained
        a valid key.
        """
        ...

    @typing.overload
    def __init__(
        self,
        device: QtCore.QIODevice,
        algorithm: QSsl.KeyAlgorithm,
        encoding: QSsl.EncodingFormat = ...,
        type: QSsl.KeyType = ...,
        passPhrase: QtCore.QByteArray = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#QSslKey-2

        **QSslKey::QSslKey(QIODevice * device , QSsl::KeyAlgorithm algorithm ,
        QSsl::EncodingFormat encoding = QSsl::Pem, QSsl::KeyType type =
        QSsl::PrivateKey, const QByteArray & passPhrase = QByteArray())**

        Constructs a QSslKey by reading and decoding data from a **device**
        using a specified **algorithm** and **encoding** format. **type**
        specifies whether the key is public or private.

        If the key is encrypted then **passPhrase** is used to decrypt it.

        After construction, use **isNull** () to check if **device** provided a
        valid key.
        """
        ...

    @typing.overload
    def __init__(self, handle: PyQt6.sip.voidptr, type: QSsl.KeyType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#QSslKey-3

        **[since 5.0] QSslKey::QSslKey(Qt::HANDLE handle , QSsl::KeyType type =
        QSsl::PrivateKey)**

        Constructs a QSslKey from a valid native key **handle**. **type**
        specifies whether the key is public or private.

        QSslKey will take ownership for this key and you must not free the key
        using the native library.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslKey") -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#QSslKey-4

        **QSslKey::QSslKey(const QSslKey & other )**

        Constructs an identical copy of **other**.
        """
        ...

    def swap(self, other: "QSslKey") -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#swap

        **[since 5.0] void QSslKey::swap(QSslKey & other )**

        Swaps this ssl key with **other**. This function is very fast and never
        fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def handle(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsslkey.html#handle

        **Qt::HANDLE QSslKey::handle() const**

        Returns a pointer to the native key handle, if there is one, else
        `nullptr`.

        You can use this handle together with the native API to access extended
        information about the key.

        **Warning:** Use of this function has a high probability of being non-
        portable, and its return value may vary across platforms, and between
        minor Qt releases.
        """
        ...

    def toDer(self, passPhrase: QtCore.QByteArray = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslkey.html#toDer

        **QByteArray QSslKey::toDer(const QByteArray & passPhrase =
        QByteArray()) const**

        Returns the key in DER encoding.

        The **passPhrase** argument should be omitted as DER cannot be
        encrypted. It will be removed in a future version of Qt.
        """
        ...

    def toPem(self, passPhrase: QtCore.QByteArray = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslkey.html#toPem

        **QByteArray QSslKey::toPem(const QByteArray & passPhrase =
        QByteArray()) const**

        Returns the key in PEM encoding. The result is encrypted with
        **passPhrase** if the key is a private key and **passPhrase** is non-
        empty.
        """
        ...

    def algorithm(self) -> QSsl.KeyAlgorithm:
        """
        https://doc.qt.io/qt-6/qsslkey.html#algorithm

        **QSsl::KeyAlgorithm QSslKey::algorithm() const**

        Returns the key algorithm.
        """
        ...

    def type(self) -> QSsl.KeyType:
        """
        https://doc.qt.io/qt-6/qsslkey.html#type

        **QSsl::KeyType QSslKey::type() const**

        Returns the type of the key (i.e., PublicKey or PrivateKey).
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslkey.html#length

        **int QSslKey::length() const**

        Returns the length of the key in bits, or -1 if the key is null.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslkey.html#clear

        **void QSslKey::clear()**

        Clears the contents of this key, making it a null key.

        **See also** **isNull** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslkey.html#isNull

        **bool QSslKey::isNull() const**

        Returns `true` if this is a null key; otherwise false.

        **See also** **clear** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QSqlDriverCreatorBase import QSqlDriverCreatorBase as QSqlDriverCreatorBase
from ._QSqlDatabase import QSqlDatabase as QSqlDatabase
from ._QSqlDriver import QSqlDriver as QSqlDriver
from ._QSqlError import QSqlError as QSqlError
from ._QSqlField import QSqlField as QSqlField
from ._QSqlRecord import QSqlRecord as QSqlRecord
from ._QSqlIndex import QSqlIndex as QSqlIndex
from ._QSqlQuery import QSqlQuery as QSqlQuery
from ._QSqlQueryModel import QSqlQueryModel as QSqlQueryModel
from ._QSqlRelationalDelegate import QSqlRelationalDelegate as QSqlRelationalDelegate
from ._QSqlRelation import QSqlRelation as QSqlRelation
from ._QSqlTableModel import QSqlTableModel as QSqlTableModel
from ._QSqlRelationalTableModel import (
    QSqlRelationalTableModel as QSqlRelationalTableModel,
)
from ._QSqlResult import QSqlResult as QSqlResult
from ._QSql import QSql as QSql



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneHoverEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html

    **Detailed Description**

    When a **QGraphicsView**  receives a **QHoverEvent**  event, it translates
    it into QGraphicsSceneHoverEvent. The event is then forwarded to the
    **QGraphicsScene**  associated with the view.

    **See also** **QGraphicsSceneMouseEvent** ,
    **QGraphicsSceneContextMenuEvent** , **QGraphicsSceneWheelEvent** , and
    **QHoverEvent** .
    """

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#modifiers

        **Qt::KeyboardModifiers QGraphicsSceneHoverEvent::modifiers() const**

        Returns the keyboard modifiers at the moment the hover event was sent.
        """
        ...

    def lastScreenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#lastScreenPos

        **QPoint QGraphicsSceneHoverEvent::lastScreenPos() const**

        Returns the last recorded mouse cursor position in screen coordinates.
        The last recorded position is the position of the previous mouse or
        hover event received by the view that created the event.

        **See also** **lastPos** (), **lastScenePos** (), and **screenPos** ().
        """
        ...

    def lastScenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#lastScenePos

        **QPointF QGraphicsSceneHoverEvent::lastScenePos() const**

        Returns the last recorded, the scene coordinates of the previous mouse
        or hover event received by the view, that created the event mouse cursor
        position in scene coordinates.

        **See also** **lastPos** (), **lastScreenPos** (), and **scenePos** ().
        """
        ...

    def lastPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#lastPos

        **QPointF QGraphicsSceneHoverEvent::lastPos() const**

        Returns the last recorded mouse cursor position in item coordinates.

        **See also** **lastScenePos** (), **lastScreenPos** (), and **pos** ().
        """
        ...

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#screenPos

        **QPoint QGraphicsSceneHoverEvent::screenPos() const**

        Returns the position of the mouse cursor in screen coordinates at the
        moment the hover event was sent.

        **See also** **pos** () and **scenePos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#scenePos

        **QPointF QGraphicsSceneHoverEvent::scenePos() const**

        Returns the position of the mouse cursor in scene coordinates at the
        moment the hover event was sent.

        **See also** **pos** () and **screenPos** ().
        """
        ...

    def pos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehoverevent.html#pos

        **QPointF QGraphicsSceneHoverEvent::pos() const**

        Returns the position of the mouse cursor in item coordinates at the
        moment the hover event was sent.

        **See also** **scenePos** () and **screenPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QUndoStack(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qundostack.html

    **Detailed Description**

    For an overview of Qt's Undo Framework, see the **overview document** .

    An undo stack maintains a stack of commands that have been applied to a
    document.

    New commands are pushed on the stack using **push** (). Commands can be
    undone and redone using **undo** () and **redo** (), or by triggering the
    actions returned by **createUndoAction** () and **createRedoAction** ().

    QUndoStack keeps track of the **current** command. This is the command which
    will be executed by the next call to **redo** (). The index of this command
    is returned by **index** (). The state of the edited object can be rolled
    forward or back using **setIndex** (). If the top-most command on the stack
    has already been redone, **index** () is equal to **count** ().

    QUndoStack provides support for undo and redo actions, command compression,
    command macros, and supports the concept of a **clean state**.

    **Undo and Redo Actions**

    QUndoStack provides convenient undo and redo **QAction**  objects, which can
    be inserted into a menu or a toolbar. When commands are undone or redone,
    QUndoStack updates the text properties of these actions to reflect what
    change they will trigger. The actions are also disabled when no command is
    available for undo or redo. These actions are returned by
    **QUndoStack::createUndoAction** () and **QUndoStack::createRedoAction** ().

    **Command Compression and Macros**

    Command compression is useful when several commands can be compressed into a
    single command that can be undone and redone in a single operation. For
    example, when a user types a character in a text editor, a new command is
    created. This command inserts the character into the document at the cursor
    position. However, it is more convenient for the user to be able to undo or
    redo typing of whole words, sentences, or paragraphs. Command compression
    allows these single-character commands to be merged into a single command
    which inserts or deletes sections of text. For more information, see
    **QUndoCommand::mergeWith** () and **push** ().

    A command macro is a sequence of commands, all of which are undone and
    redone in one go. Command macros are created by giving a command a list of
    child commands. Undoing or redoing the parent command will cause the child
    commands to be undone or redone. Command macros may be created explicitly by
    specifying a parent in the **QUndoCommand**  constructor, or by using the
    convenience functions **beginMacro** () and **endMacro** ().

    Although command compression and macros appear to have the same effect to
    the user, they often have different uses in an application. Commands that
    perform small changes to a document may be usefully compressed if there is
    no need to individually record them, and if only larger changes are relevant
    to the user. However, for commands that need to be recorded individually, or
    those that cannot be compressed, it is useful to use macros to provide a
    more convenient user experience while maintaining a record of each command.

    **Clean State**

    QUndoStack supports the concept of a clean state. When the document is saved
    to disk, the stack can be marked as clean using **setClean** (). Whenever
    the stack returns to this state through undoing and redoing commands, it
    emits the signal **cleanChanged** (). This signal is also emitted when the
    stack leaves the clean state. This signal is usually used to enable and
    disable the save actions in the application, and to update the document's
    title to reflect that it contains unsaved changes.

    **Obsolete Commands**

    QUndoStack is able to delete commands from the stack if the command is no
    longer needed. One example may be to delete a command when two commands are
    merged together in such a way that the merged command has no function. This
    can be seen with move commands where the user moves their mouse to one part
    of the screen and then moves it to the original position. The merged command
    results in a mouse movement of 0. This command can be deleted since it
    serves no purpose. Another example is with networking commands that fail due
    to connection issues. In this case, the command is to be removed from the
    stack because the **redo** () and **undo** () functions have no function
    since there was connection issues.

    A command can be marked obsolete with the **QUndoCommand::setObsolete** ()
    function. The **QUndoCommand::isObsolete** () flag is checked in
    **QUndoStack::push** (), **QUndoStack::undo** (), **QUndoStack::redo** (),
    and **QUndoStack::setIndex** () after calling **QUndoCommand::undo** (),
    **QUndoCommand::redo** () and **QUndoCommand** :mergeWith() where
    applicable.

    If a command is set obsolete and the clean index is greater than or equal to
    the current command index, then the clean index will be reset when the
    command is deleted from the stack.

    **See also** **QUndoCommand**  and **QUndoView** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#QUndoStack

        **QUndoStack::QUndoStack(QObject * parent = nullptr)**

        Constructs an empty undo stack with the parent **parent**. The stack
        will initially be in the clean state. If **parent** is a **QUndoGroup**
        object, the stack is automatically added to the group.

        **See also** **push** ().
        """
        ...

    def command(self, index: int) -> QUndoCommand:
        """
        https://doc.qt.io/qt-6/qundostack.html#command

        **const QUndoCommand *QUndoStack::command(int index ) const**

        Returns a const pointer to the command at **index**.

        This function returns a const pointer, because modifying a command, once
        it has been pushed onto the stack and executed, almost always causes
        corruption of the state of the document, if the command is later undone
        or redone.

        **See also** **QUndoCommand::child** ().
        """
        ...

    def undoLimit(self) -> int:
        """
        https://doc.qt.io/qt-6/qundostack.html#undoLimit-prop

        **undoLimit : int**

        This property holds the maximum number of commands on this stack.

        When the number of commands on a stack exceedes the stack's undoLimit,
        commands are deleted from the bottom of the stack. Macro commands
        (commands with child commands) are treated as one command. The default
        value is 0, which means that there is no limit.

        This property may only be set when the undo stack is empty, since
        setting it on a non-empty stack might delete the command at the current
        index. Calling setUndoLimit() on a non-empty stack prints a warning and
        does nothing.

        **Access functions:**

        int **undoLimit** () const
        void **setUndoLimit** (int **limit** )
        """
        ...

    def setUndoLimit(self, limit: int) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#undoLimit-prop

        **undoLimit : int**

        This property holds the maximum number of commands on this stack.

        When the number of commands on a stack exceedes the stack's undoLimit,
        commands are deleted from the bottom of the stack. Macro commands
        (commands with child commands) are treated as one command. The default
        value is 0, which means that there is no limit.

        This property may only be set when the undo stack is empty, since
        setting it on a non-empty stack might delete the command at the current
        index. Calling setUndoLimit() on a non-empty stack prints a warning and
        does nothing.

        **Access functions:**

        int **undoLimit** () const
        void **setUndoLimit** (int **limit** )
        """
        ...

    def resetClean(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#resetClean

        **[slot, since 5.8] void QUndoStack::resetClean()**

        Leaves the clean state and emits **cleanChanged** () if the stack was
        clean. This method resets the clean index to -1.

        This is typically called in the following cases, when a document has
        been:

        * created basing on some template and has not been saved, so no filename
        has been associated with the document yet.
          * restored from a backup
        file.
          * changed outside of the editor and the user did not reload it.

        This function was introduced in Qt 5.8.

        **See also** **isClean** (), **setClean** (), and **cleanIndex** ().
        """
        ...

    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#undo

        **[slot] void QUndoStack::undo()**

        Undoes the command below the current command by calling
        **QUndoCommand::undo** (). Decrements the current command index.

        If the stack is empty, or if the bottom command on the stack has already
        been undone, this function does nothing.

        After the command is undone, if **QUndoCommand::isObsolete** () returns
        `true`, then the command will be deleted from the stack. Additionally,
        if the clean index is greater than or equal to the current command
        index, then the clean index is reset.

        **See also** **redo** () and **index** ().
        """
        ...

    def setIndex(self, idx: int) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#setIndex

        **[slot] void QUndoStack::setIndex(int idx )**

        Repeatedly calls **undo** () or **redo** () until the current command
        index reaches **idx**. This function can be used to roll the state of
        the document forwards of backwards. **indexChanged** () is emitted only
        once.

        **See also** **index** (), **count** (), **undo** (), and **redo** ().
        """
        ...

    def setClean(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#setClean

        **[slot] void QUndoStack::setClean()**

        Marks the stack as clean and emits **cleanChanged** () if the stack was
        not already clean.

        This is typically called when a document is saved, for example.

        Whenever the stack returns to this state through the use of undo/redo
        commands, it emits the signal **cleanChanged** (). This signal is also
        emitted when the stack leaves the clean state.

        **See also** **isClean** (), **resetClean** (), and **cleanIndex** ().
        """
        ...

    def setActive(self, active: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#active-prop

        **active : bool**

        This property holds the active status of this stack.

        An application often has multiple undo stacks, one for each opened
        document. The active stack is the one associated with the currently
        active document. If the stack belongs to a **QUndoGroup** , calls to
        **QUndoGroup::undo** () or **QUndoGroup::redo** () will be forwarded to
        this stack when it is active. If the **QUndoGroup**  is watched by a
        **QUndoView** , the view will display the contents of this stack when it
        is active. If the stack does not belong to a **QUndoGroup** , making it
        active has no effect.

        It is the programmer's responsibility to specify which stack is active
        by calling setActive(), usually when the associated document window
        receives focus.

        **Access functions:**

        bool **isActive** () const
        void **setActive** (bool **active** = true)

        **See also** **QUndoGroup** .
        """
        ...

    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#redo

        **[slot] void QUndoStack::redo()**

        Redoes the current command by calling **QUndoCommand::redo** ().
        Increments the current command index.

        If the stack is empty, or if the top command on the stack has already
        been redone, this function does nothing.

        If **QUndoCommand::isObsolete** () returns true for the current command,
        then the command will be deleted from the stack. Additionally, if the
        clean index is greater than or equal to the current command index, then
        the clean index is reset.

        **See also** **undo** () and **index** ().
        """
        ...

    def endMacro(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#endMacro

        **void QUndoStack::endMacro()**

        Ends composition of a macro command.

        If this is the outermost macro in a set nested macros, this function
        emits **indexChanged** () once for the entire macro command.

        **See also** **beginMacro** ().
        """
        ...

    def beginMacro(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#beginMacro

        **void QUndoStack::beginMacro(const QString & text )**

        Begins composition of a macro command with the given **text**
        description.

        An empty command described by the specified **text** is pushed on the
        stack. Any subsequent commands pushed on the stack will be appended to
        the empty command's children until **endMacro** () is called.

        Calls to beginMacro() and **endMacro** () may be nested, but every call
        to beginMacro() must have a matching call to **endMacro** ().

        While a macro is being composed, the stack is disabled. This means that:

        * **indexChanged** () and **cleanChanged** () are not emitted,
          *
        **canUndo** () and **canRedo** () return false,
          * calling **undo** ()
        or **redo** () has no effect,
          * the undo/redo actions are disabled.

        The stack becomes enabled and appropriate signals are emitted when
        **endMacro** () is called for the outermost macro.

        stack.beginMacro("insert red text");
            stack.push(new
        InsertText(document, idx, text));
            stack.push(new SetColor(document,
        idx, text.length(), Qt::red));
            stack.endMacro(); // indexChanged()
        is emitted

        This code is equivalent to:

        **QUndoCommand**  *insertRed = new **QUndoCommand** (); // an empty
        command
            insertRed->setText("insert red text");

            new
        InsertText(document, idx, text, insertRed); // becomes child of
        insertRed
            new SetColor(document, idx, text.length(), Qt::red,
        insertRed);

            stack.push(insertRed);

        **See also** **endMacro** ().
        """
        ...

    def cleanIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qundostack.html#cleanIndex

        **int QUndoStack::cleanIndex() const**

        Returns the clean index. This is the index at which **setClean** () was
        called.

        A stack may not have a clean index. This happens if a document is saved,
        some commands are undone, then a new command is pushed. Since **push**
        () deletes all the undone commands before pushing the new command, the
        stack can't return to the clean state again. In this case, this function
        returns -1. The -1 may also be returned after an explicit call to
        **resetClean** ().

        **See also** **isClean** () and **setClean** ().
        """
        ...

    def isClean(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundostack.html#isClean

        **bool QUndoStack::isClean() const**

        If the stack is in the clean state, returns `true`; otherwise returns
        `false`.

        **Note:** Getter function for property **clean** .

        **See also** **setClean** () and **cleanIndex** ().
        """
        ...

    def isActive(self) -> bool:
        ...

    def createRedoAction(self, parent: QtCore.QObject, prefix: str = ...) -> QAction:
        """
        https://doc.qt.io/qt-6/qundostack.html#createRedoAction

        **QAction *QUndoStack::createRedoAction(QObject * parent , const QString
        & prefix = QString()) const**

        Creates an redo **QAction**  object with the given **parent**.

        Triggering this action will cause a call to **redo** (). The text of
        this action is the text of the command which will be redone in the next
        call to **redo** (), prefixed by the specified **prefix**. If there is
        no command available for redo, this action will be disabled.

        If **prefix** is empty, the default template "Redo %1" is used instead
        of prefix. Before Qt 4.8, the prefix "Redo" was used by default.

        **See also** **createUndoAction** (), **canRedo** (), and
        **QUndoCommand::text** ().
        """
        ...

    def createUndoAction(self, parent: QtCore.QObject, prefix: str = ...) -> QAction:
        """
        https://doc.qt.io/qt-6/qundostack.html#createUndoAction

        **QAction *QUndoStack::createUndoAction(QObject * parent , const QString
        & prefix = QString()) const**

        Creates an undo **QAction**  object with the given **parent**.

        Triggering this action will cause a call to **undo** (). The text of
        this action is the text of the command which will be undone in the next
        call to **undo** (), prefixed by the specified **prefix**. If there is
        no command available for undo, this action will be disabled.

        If **prefix** is empty, the default template "Undo %1" is used instead
        of prefix. Before Qt 4.8, the prefix "Undo" was used by default.

        **See also** **createRedoAction** (), **canUndo** (), and
        **QUndoCommand::text** ().
        """
        ...

    def text(self, idx: int) -> str:
        """
        https://doc.qt.io/qt-6/qundostack.html#text

        **QString QUndoStack::text(int idx ) const**

        Returns the text of the command at index **idx**.

        **See also** **beginMacro** ().
        """
        ...

    def index(self) -> int:
        """
        https://doc.qt.io/qt-6/qundostack.html#index

        **int QUndoStack::index() const**

        Returns the index of the current command. This is the command that will
        be executed on the next call to **redo** (). It is not always the top-
        most command on the stack, since a number of commands may have been
        undone.

        **See also** **setIndex** (), **undo** (), **redo** (), and **count**
        ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qundostack.html#count

        **int QUndoStack::count() const**

        Returns the number of commands on the stack. Macro commands are counted
        as one command.

        **See also** **index** (), **setIndex** (), and **command** ().
        """
        ...

    def redoText(self) -> str:
        """
        https://doc.qt.io/qt-6/qundostack.html#redoText

        **QString QUndoStack::redoText() const**

        Returns the text of the command which will be redone in the next call to
        **redo** ().

        **Note:** Getter function for property redoText.

        **See also** **QUndoCommand::actionText** () and **undoText** ().
        """
        ...

    def undoText(self) -> str:
        """
        https://doc.qt.io/qt-6/qundostack.html#undoText

        **QString QUndoStack::undoText() const**

        Returns the text of the command which will be undone in the next call to
        **undo** ().

        **Note:** Getter function for property undoText.

        **See also** **QUndoCommand::actionText** () and **redoText** ().
        """
        ...

    def canRedo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundostack.html#canRedo

        **bool QUndoStack::canRedo() const**

        Returns `true` if there is a command available for redo; otherwise
        returns `false`.

        This function returns `false` if the stack is empty or if the top
        command on the stack has already been redone.

        Synonymous with **index** () == **count** ().

        **Note:** Getter function for property canRedo.

        **See also** **index** () and **canUndo** ().
        """
        ...

    def canUndo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundostack.html#canUndo

        **bool QUndoStack::canUndo() const**

        Returns `true` if there is a command available for undo; otherwise
        returns `false`.

        This function returns `false` if the stack is empty, or if the bottom
        command on the stack has already been undone.

        Synonymous with **index** () == 0.

        **Note:** Getter function for property canUndo.

        **See also** **index** () and **canRedo** ().
        """
        ...

    def push(self, cmd: QUndoCommand) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#push

        **void QUndoStack::push(QUndoCommand * cmd )**

        Pushes **cmd** on the stack or merges it with the most recently executed
        command. In either case, executes **cmd** by calling its **redo** ()
        function.

        If **cmd** 's id is not -1, and if the id is the same as that of the
        most recently executed command, **QUndoStack**  will attempt to merge
        the two commands by calling **QUndoCommand::mergeWith** () on the most
        recently executed command. If **QUndoCommand::mergeWith** () returns
        `true`, **cmd** is deleted.

        After calling **QUndoCommand::redo** () and, if applicable,
        **QUndoCommand::mergeWith** (), **QUndoCommand::isObsolete** () will be
        called for **cmd** or the merged command. If
        **QUndoCommand::isObsolete** () returns `true`, then **cmd** or the
        merged command will be deleted from the stack.

        In all other cases **cmd** is simply pushed on the stack.

        If commands were undone before **cmd** was pushed, the current command
        and all commands above it are deleted. Hence **cmd** always ends up
        being the top-most on the stack.

        Once a command is pushed, the stack takes ownership of it. There are no
        getters to return the command, since modifying it after it has been
        executed will almost always lead to corruption of the document's state.

        **See also** **QUndoCommand::id** () and **QUndoCommand::mergeWith** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qundostack.html#clear

        **void QUndoStack::clear()**

        Clears the command stack by deleting all commands on it, and returns the
        stack to the clean state.

        Commands are not undone or redone; the state of the edited object
        remains unchanged.

        This function is usually used when the contents of the document are
        abandoned.

        **See also** **QUndoStack** ().
        """
        ...

    @property
    def canRedoChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#canRedoChanged

        **[signal] void QUndoStack::canRedoChanged(bool canRedo )**

        This signal is emitted whenever the value of **canRedo** () changes. It
        is used to enable or disable the redo action returned by
        **createRedoAction** (). **canRedo** specifies the new value.

        **Note:** Notifier signal for property **canRedo** .
        """
        ...

    @property
    def canUndoChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#canUndoChanged

        **[signal] void QUndoStack::canUndoChanged(bool canUndo )**

        This signal is emitted whenever the value of **canUndo** () changes. It
        is used to enable or disable the undo action returned by
        **createUndoAction** (). **canUndo** specifies the new value.

        **Note:** Notifier signal for property **canUndo** .
        """
        ...

    @property
    def cleanChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#cleanChanged

        **[signal] void QUndoStack::cleanChanged(bool clean )**

        This signal is emitted whenever the stack enters or leaves the clean
        state. If **clean** is true, the stack is in a clean state; otherwise
        this signal indicates that it has left the clean state.

        **Note:** Notifier signal for property **clean** .

        **See also** **isClean** () and **setClean** ().
        """
        ...

    @property
    def indexChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#indexChanged

        **[signal] void QUndoStack::indexChanged(int idx )**

        This signal is emitted whenever a command modifies the state of the
        document. This happens when a command is undone or redone. When a macro
        command is undone or redone, or **setIndex** () is called, this signal
        is emitted only once.

        **idx** specifies the index of the current command, ie. the command
        which will be executed on the next call to **redo** ().

        **See also** **index** () and **setIndex** ().
        """
        ...

    @property
    def redoTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#redoTextChanged

        **[signal] void QUndoStack::redoTextChanged(const QString & redoText )**

        This signal is emitted whenever the value of **redoText** () changes. It
        is used to update the text property of the redo action returned by
        **createRedoAction** (). **redoText** specifies the new text.

        **Note:** Notifier signal for property **redoText** .
        """
        ...

    @property
    def undoTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundostack.html#undoTextChanged

        **[signal] void QUndoStack::undoTextChanged(const QString & undoText )**

        This signal is emitted whenever the value of **undoText** () changes. It
        is used to update the text property of the undo action returned by
        **createUndoAction** (). **undoText** specifies the new text.

        **Note:** Notifier signal for property **undoText** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QQuickGraphicsConfiguration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html

    **Detailed Description**

    When constructing and showing a **QQuickWindow**  that uses Vulkan to
    render, a Vulkan instance (`VkInstance`), a physical device
    (`VkPhysicalDevice`), a device (`VkDevice`) and associated objects (queues,
    pools) are initialized through the Vulkan API. The same is mostly true when
    using **QQuickRenderControl**  to redirect the rendering into a custom
    render target, such as a texture. While **QVulkanInstance**  construction is
    under the application's control then, the initialization of other graphics
    objects happen the same way in **QQuickRenderControl::initialize** () as
    with an on-screen **QQuickWindow** .

    For the majority of applications no additional configuration is needed
    because Qt Quick provides reasonable defaults for many low-level graphics
    settings, for example which device extensions to enable.

    This will not alway be sufficient, however. In advanced use cases, when
    integrating direct Vulkan or other graphics API content, or when integrating
    with an external 3D or VR engine, such as, OpenXR, the application will want
    to specify its own set of settings when it comes to details, such as which
    device extensions to enable.

    That is what this class enables. It allows specifying, for example, a list
    of device extensions that is then picked up by the scene graph when using
    Vulkan, or graphics APIs where the concept is applicable. Where some
    concepts are not applicable, the related settings are simply ignored.

    Another class of settings are related to the scene graph's renderer. In some
    cases applications may want to control certain behavior,such as using the
    depth buffer when rendering 2D content. In Qt 5 such settings were either
    not controllable at all, or were managed through environment variables. In
    Qt 6, QQuickGraphicsConfiguration provides a new home for these settings,
    while keeping support for the legacy environment variables, where
    applicable.

    **Note:** Setting a QQuickGraphicsConfiguration on a **QQuickWindow**  must
    happen early enough, before the scene graph is initialized for the first
    time for that window. With on-screen windows this means the call must be
    done before invoking show() on the **QQuickWindow**  or **QQuickView** .
    With **QQuickRenderControl**  the configuration must be finalized before
    calling **initialize** ().

    **See also** **QQuickWindow::setGraphicsConfiguration** (), **QQuickWindow**
    , and **QQuickRenderControl** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#QQuickGraphicsCo
        nfiguration

        **QQuickGraphicsConfiguration::QQuickGraphicsConfiguration()**

        Constructs a default QQuickGraphicsConfiguration that does not specify
        any additional settings for the scene graph to take into account.
        """
        ...

    @typing.overload
    def __init__(self, other: "QQuickGraphicsConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#QQuickGraphicsCo
        nfiguration

        **QQuickGraphicsConfiguration::QQuickGraphicsConfiguration()**

        Constructs a default QQuickGraphicsConfiguration that does not specify
        any additional settings for the scene graph to take into account.
        """
        ...

    @staticmethod
    def preferredInstanceExtensions() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#preferredInstanc
        eExtensions

        **[static, since 6.1] QByteArrayList
        QQuickGraphicsConfiguration::preferredInstanceExtensions()**

        Returns the list of Vulkan instance extensions Qt Quick prefers to have
        enabled on the VkInstance.

        In most cases Qt Quick is responsible for creating a **QVulkanInstance**
        . This function is not relevant then. On the other hand, when using
        **QQuickRenderControl**  in combination with Vulkan-based rendering, it
        is the application's responsibility to create a **QVulkanInstance**  and
        associate it with the (offscreen) **QQuickWindow** . In this case, it is
        expected that the application queries the list of instance extensions to
        enable, and passes them to **QVulkanInstance::setExtensions** () before
        calling **QVulkanInstance::create** ().

        This function was introduced in Qt 6.1.
        """
        ...

    def isDepthBufferEnabledFor2D(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#isDepthBufferEna
        bledFor2D

        **bool QQuickGraphicsConfiguration::isDepthBufferEnabledFor2D() const**

        Returns true if depth buffer usage is enabled for 2D content.

        By default the value is true, unless the `QSG_NO_DEPTH_BUFFER`
        environment variable is set.
        """
        ...

    def setDepthBufferFor2D(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#setDepthBufferFo
        r2D

        **void QQuickGraphicsConfiguration::setDepthBufferFor2D(bool enable )**

        Sets the usage of depth buffer for 2D content to **enable**. When
        disabled, the Qt Quick scene graph never writes into the depth buffer.

        By default the value is true, unless the `QSG_NO_DEPTH_BUFFER`
        environment variable is set.

        The default value of true is the most optimal setting for the vast
        majority of scenes. Disabling depth buffer usage reduces the efficiency
        of the scene graph's batching.

        There are cases however, when allowing the 2D content write to the depth
        buffer is not ideal. Consider a 3D scene as an "overlay" on top the 2D
        scene, rendered via Qt Quick 3D using a **View3D**  with **renderMode**
        set to `Overlay`. In this case, having the depth buffer filled by 2D
        content can cause unexpected results. This is because the way the 2D
        scene graph renderer generates and handles depth values is not
        necessarily compatible with how a 3D scene works. This may end up in
        depth value clashes, collisions, and unexpected depth test failures.
        Therefore, the robust approach here is to call this function with
        **enable** set to false, and disable depth buffer writes for the 2D
        content in the **QQuickWindow** .

        **Note:** This flag is not fully identical to setting the
        `QSG_NO_DEPTH_BUFFER` environment variable. This flag does not control
        the depth-stencil buffers' presence. It is rather relevant for the
        rendering pipeline. To force not having depth/stencil attachments at
        all, set `QSG_NO_DEPTH_BUFFER` and `QSG_NO_STENCIL_BUFFER`. Be aware
        however that such a **QQuickWindow** , and any Item layers in it, may
        then become incompatible with items, such as **View3D**  with certain
        operating modes, because 3D content requires a depth buffer. Calling
        this function is always safe, but can mean that resources, such as depth
        buffers, are created even though they are not actively used.
        """
        ...

    def deviceExtensions(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#deviceExtensions

        **QByteArrayList QQuickGraphicsConfiguration::deviceExtensions() const**

        Returns the list of the requested additional device extensions.

        **See also** **setDeviceExtensions** ().
        """
        ...

    def setDeviceExtensions(
        self, extensions: typing.Iterable[QtCore.QByteArray]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsconfiguration.html#setDeviceExtensi
        ons

        **void QQuickGraphicsConfiguration::setDeviceExtensions(const
        QByteArrayList & extensions )**

        Sets the list of additional **extensions** to enable on the graphics
        device (such as, the `VkDevice`).

        When rendering with a graphics API where the concept is not applicable,
        **extensions** will be ignored.

        **Note:** The list specifies additional, extra extensions. Qt Quick
        always enables extensions that are required by the scene graph.

        **See also** **deviceExtensions** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGFlatColorMaterial(QSGMaterial):
    """
    https://doc.qt.io/qt-6/qsgflatcolormaterial.html

    **Detailed Description**

    **Warning:** This utility class is only functional when running with the
    default backend of the Qt Quick scenegraph.

    The flat color material will fill every pixel in a geometry using a solid
    color. The color can contain transparency.

    The geometry to be rendered with a flat color material requires vertices in
    attribute location 0 in the **QSGGeometry**  object to render correctly. The
    **QSGGeometry::defaultAttributes_Point2D** () returns an attribute set
    compatible with this material.

    The flat color material respects both current opacity and current matrix
    when updating its rendering state.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgflatcolormaterial.html#QSGFlatColorMaterial

        **QSGFlatColorMaterial::QSGFlatColorMaterial()**

        Constructs a new flat color material.

        The default color is white.
        """
        ...

    def compare(self, other: QSGMaterial) -> int:
        ...

    def color(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qsgflatcolormaterial.html#color

        **const QColor &QSGFlatColorMaterial::color() const**

        Returns this flat color material's color.

        The default color is white.

        **See also** **setColor** ().
        """
        ...

    def setColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgflatcolormaterial.html#setColor

        **void QSGFlatColorMaterial::setColor(const QColor & color )**

        Sets this flat color material's color to **color**.

        **See also** **color** ().
        """
        ...

    def createShader(
        self, renderMode: "QSGRendererInterface.RenderMode"
    ) -> "QSGMaterialShader":
        ...

    def type(self) -> "QSGMaterialType":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6.QtQuick import *


class QSGTransformNode(QSGNode):
    """
    https://doc.qt.io/qt-6/qsgtransformnode.html

    **Detailed Description**

    Transformations apply the node's subtree and can be nested. Multiple
    transform nodes will be accumulated by intersecting all their matrices. The
    accumulation happens as part of the rendering.

    The transform nodes implement a 4x4 matrix which in theory supports full 3D
    transformations. However, because the renderer optimizes for 2D use-cases
    rather than 3D use-cases, rendering a scene with full 3D transformations
    needs to be done with some care.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgtransformnode.html#QSGTransformNode

        **QSGTransformNode::QSGTransformNode()**

        Create a new QSGTransformNode with its matrix set to the identity
        matrix.
        """
        ...

    def matrix(self) -> QtGui.QMatrix4x4:
        """
        https://doc.qt.io/qt-6/qsgtransformnode.html#matrix

        **const QMatrix4x4 &QSGTransformNode::matrix() const**

        Returns this transform node's matrix.

        **See also** **setMatrix** ().
        """
        ...

    def setMatrix(self, matrix: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qsgtransformnode.html#setMatrix

        **void QSGTransformNode::setMatrix(const QMatrix4x4 & matrix )**

        Sets this transform node's matrix to **matrix**.

        **See also** **matrix** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamNotationDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html

    **Detailed Description**

    An notation declaration consists of a **name** (), a **systemId** (), and a
    **publicId** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#QXmlStreamNota
        tionDeclaration

        **QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()**

        Creates an empty notation declaration.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamNotationDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#QXmlStreamNota
        tionDeclaration

        **QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()**

        Creates an empty notation declaration.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#publicId

        **QStringView QXmlStreamNotationDeclaration::publicId() const**

        Returns the public identifier.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#systemId

        **QStringView QXmlStreamNotationDeclaration::systemId() const**

        Returns the system identifier.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#name

        **QStringView QXmlStreamNotationDeclaration::name() const**

        Returns the notation name.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNfc import *
import enum


class QNdefRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qndefrecord.html

    **Detailed Description**

    QNdefRecord and derived classes are used to parse the contents of **NDEF
    messages**  and create new NDEF messages.

    Use **typeNameFormat** () and **setTypeNameFormat** () to get and set the
    type name format of the NDEF record.

    Use **type** () and **setType** () to get and set the type of the NDEF
    record.

    Use **id** () and **setId** () to get and set the id of the NDEF record.

    Use **payload** () and **setPayload** () to get and set the NDEF record
    payload. **isEmpty** () can be used to test if the payload is empty.

    QNdefRecord is an implicitly shared class. This means you can efficiently
    convert between QNdefRecord and specialized record classes. The
    **isRecordType** () template function can be used to test if a conversion is
    possible. The following example shows how to test if a QNdefRecord is an NFC
    RTD Text record and extract the text information from it.

    if (record.isRecordType<**QNdefNfcTextRecord** >()) {
    **QNdefNfcTextRecord**  textRecord(record);

            **qDebug** () <<
    textRecord.text();
        }

    **Creating Specialized NDEF Record Classes**

    Specialized NDEF record classes can be easily created with the
    **Q_DECLARE_NDEF_RECORD** () and **Q_DECLARE_ISRECORDTYPE_FOR_NDEF_RECORD**
    () macros. The following example shows the class declaration of the
    hypothetical **example.com:f** record type that encapsulates a single int
    property foo.

    class ExampleComF : public **QNdefRecord**
        {
        public:
    Q_DECLARE_NDEF_RECORD(ExampleComF, **QNdefRecord** ::ExternalRtd,
    "example.com:f",
                                  **QByteArray** (sizeof(int),
    char(0)))

            int foo() const;
            void setFoo(int v);
        };
    Q_DECLARE_ISRECORDTYPE_FOR_NDEF_RECORD(ExampleComF, **QNdefRecord**
    ::ExternalRtd, "example.com:f")

    The developer only needs to provide implementations for the `foo()` and
    `setFoo()` functions that parse and set the contents of the NDEF record's
    payload.
    """

    class TypeNameFormat(enum.Enum):
        Empty: QNdefRecord = ...
        NfcRtd: QNdefRecord = ...
        Mime: QNdefRecord = ...
        Uri: QNdefRecord = ...
        ExternalRtd: QNdefRecord = ...
        Unknown: QNdefRecord = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#QNdefRecord

        **QNdefRecord::QNdefRecord()**

        Constructs a new empty NDEF record.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNdefRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#QNdefRecord-1

        **QNdefRecord::QNdefRecord(const QNdefRecord & other )**

        Constructs a new NDEF record that is a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#clear

        **[since 6.2] void QNdefRecord::clear()**

        Clear the NDEF record.

        An **isEmpty** () call returns `true` for a cleared record. The record
        **type** () is set to **Empty** .

        This function was introduced in Qt 6.2.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#isEmpty

        **bool QNdefRecord::isEmpty() const**

        Returns `true` if the NDEF record contains an empty payload; otherwise
        returns `false`.

        This is equivalent to calling `payload().isEmpty()`.
        """
        ...

    def payload(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#payload

        **QByteArray QNdefRecord::payload() const**

        Returns the payload of the NDEF record.

        **See also** **setPayload** ().
        """
        ...

    def setPayload(self, payload: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#setPayload

        **void QNdefRecord::setPayload(const QByteArray & payload )**

        Sets the payload of the NDEF record to **payload**.

        **See also** **payload** ().
        """
        ...

    def id(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#id

        **QByteArray QNdefRecord::id() const**

        Returns the id of the NDEF record.

        **See also** **setId** ().
        """
        ...

    def setId(self, id: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#setId

        **void QNdefRecord::setId(const QByteArray & id )**

        Sets the id of the NDEF record to **id**.

        **See also** **id** ().
        """
        ...

    def type(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#type

        **QByteArray QNdefRecord::type() const**

        Returns the type of the NDEF record.

        **See also** **setType** ().
        """
        ...

    def setType(self, type: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#setType

        **void QNdefRecord::setType(const QByteArray & type )**

        Sets the type of the NDEF record to **type**.

        **See also** **type** ().
        """
        ...

    def typeNameFormat(self) -> "QNdefRecord.TypeNameFormat":
        """
        https://doc.qt.io/qt-6/qndefrecord.html#typeNameFormat

        **QNdefRecord::TypeNameFormat QNdefRecord::typeNameFormat() const**

        Returns the type name format of the NDEF record.

        **See also** **setTypeNameFormat** ().
        """
        ...

    def setTypeNameFormat(self, typeNameFormat: "QNdefRecord.TypeNameFormat") -> None:
        """
        https://doc.qt.io/qt-6/qndefrecord.html#setTypeNameFormat

        **void QNdefRecord::setTypeNameFormat(QNdefRecord::TypeNameFormat
        typeNameFormat )**

        Sets the type name format of the NDEF record to **typeNameFormat**.

        **See also** **typeNameFormat** ().
        """
        ...
